### S3 Browser - Chat Threads

<script type="module" src="/web_components/js/elements/ui/WebC__S3_Browser__Chat_Threads.mjs"></script>

<webc-s3-browser-chat-threads api_path="/api/server/requests-in-s3/list-folders"  ></webc-s3-browser-chat-threads>
